@@ -24,12 +24,9 @@ import warnings
 import yaml
 
 import jinja2
-from swiftclient import exceptions as swiftexceptions
 
 from tripleo_common import constants
 from tripleo_common.utils.safe_import import git
-from tripleo_common.utils import swift as swiftutils
-from tripleo_common.utils import tarball
 
 LOG = logging.getLogger(__name__)
 
@@ -434,6 +431,9 @@ class Config(object):
                 raise Exception(err_msg)
 
             role = self.get_role_from_server_id(stack, server_id)
+            server_pre_network = server_deployment_names.setdefault(
+                server_names[server_id], {}).setdefault(
+                'pre_network', [])
             server_pre_deployments = server_deployment_names.setdefault(
                 server_names[server_id], {}).setdefault(
                 'pre_deployments', [])
@@ -451,6 +451,9 @@ class Config(object):
                     'PostConfig' in deployment.physical_resource_id:
                 if deployment_name not in server_post_deployments:
                     server_post_deployments.append(deployment_name)
+            elif 'PreNetworkConfig' in deployment.physical_resource_id:
+                if deployment_name not in server_pre_network:
+                    server_pre_network.append(deployment_name)
             else:
                 if deployment_name not in server_pre_deployments:
                     server_pre_deployments.append(deployment_name)
@@ -543,6 +546,8 @@ class Config(object):
                     role_host_vars[role][server],
                     default_flow_style=False) if role_host_vars else None)
 
+            pre_network = server_deployment_names.get(
+                server, {}).get('pre_network', [])
             pre_deployments = server_deployment_names.get(
                 server, {}).get('pre_deployments', [])
             post_deployments = server_deployment_names.get(
@@ -551,6 +556,7 @@ class Config(object):
             with open(host_var_server_path, 'w') as f:
                 template_data = host_var_server_template.render(
                     role=role,
+                    pre_network=pre_network,
                     pre_deployments=pre_deployments,
                     post_deployments=post_deployments,
                     ansible_host_vars=ansible_host_vars)
@@ -586,36 +592,18 @@ class Config(object):
         return config_dir
 
 
-def get_overcloud_config(swift, heat,
+def get_overcloud_config(swift=None, heat=None,
                          container=constants.DEFAULT_CONTAINER_NAME,
                          container_config=constants.CONFIG_CONTAINER_NAME,
                          config_dir=None, config_type=None,
                          preserve_config=False):
+    if heat is None:
+        raise RuntimeError('Should provide orchestration client to fetch '
+                           ' TripleO config')
     if not config_dir:
         config_dir = tempfile.mkdtemp(prefix='tripleo-',
                                       suffix='-config')
 
-    if swift:
-        # Since the config-download directory is now a git repo, first download
-        # the existing config container if it exists so we can reuse the
-        # existing git repo.
-        try:
-            swiftutils.download_container(swift, container_config,
-                                          config_dir)
-            # Delete the existing container before we re-upload, otherwise
-            # files may not be fully overwritten.
-            swiftutils.delete_container(swift, container_config)
-        except swiftexceptions.ClientException as err:
-            if err.http_status != 404:
-                raise
-
-    # Delete downloaded tarball as it will be recreated later and we don't
-    # want to include the old tarball in the new tarball.
-    old_tarball_path = os.path.join(
-        config_dir, '%s.tar.gz' % container_config)
-    if os.path.exists(old_tarball_path):
-        os.unlink(old_tarball_path)
-
     config = Config(heat)
     message = "Automatic commit with fresh config download\n\n"
 
@@ -624,33 +612,6 @@ def get_overcloud_config(swift, heat,
                                          preserve_config_dir=True,
                                          commit_message=message)
 
-    if swift:
-        with tempfile.NamedTemporaryFile() as tmp_tarball:
-            tarball.create_tarball(config_path, tmp_tarball.name,
-                                   excludes=['.tox', '*.pyc', '*.pyo'])
-            tarball.tarball_extract_to_swift_container(
-                swift,
-                tmp_tarball.name,
-                container_config)
-            # Also upload the tarball to the container for use by export later
-            with open(tmp_tarball.name, 'rb') as t:
-                swift.put_object(container_config,
-                                 '%s.tar.gz' % container_config, t)
     if not preserve_config:
         if os.path.exists(config_path):
             shutil.rmtree(config_path)
-
-
-def download_overcloud_config(swift,
-                              container_config=constants.CONFIG_CONTAINER_NAME,
-                              work_dir=None):
-    if not work_dir:
-        work_dir = tempfile.mkdtemp(prefix='tripleo-', suffix='-config')
-
-    swiftutils.download_container(swift, container_config, work_dir)
-    symlink_path = os.path.join(
-        os.path.dirname(work_dir), 'config-download-latest')
-    if os.path.exists(symlink_path):
-        os.unlink(symlink_path)
-    os.symlink(work_dir, symlink_path)
-    return work_dir
